==================================
``psyclone.psyir.nodes.directive``
==================================

.. automodule:: psyclone.psyir.nodes.directive

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.directive


Classes
=======

- :py:class:`Directive`:
  Abstract base class for all Directive statements.

- :py:class:`RegionDirective`:
  Base class for all Directive nodes that have an associated

- :py:class:`StandaloneDirective`:
  Base class for all StandaloneDirective statements. This class is


.. autoclass:: Directive
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Directive
      :parts: 1

.. autoclass:: RegionDirective
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: RegionDirective
      :parts: 1

.. autoclass:: StandaloneDirective
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: StandaloneDirective
      :parts: 1
